@@ -1,14 +1,14 @@
 import time
 from abc import ABC, abstractmethod
-from typing import AsyncGenerator, List, Optional, Union
+from typing import Any, AsyncGenerator, AsyncIterator, List, Optional, Union
 
 import jwt
 
-from simple_github.client import Client
+from simple_github.client import AsyncClient
 
 
 # For compatibility with Python <3.10.
-async def anext(ait):
+async def anext(ait: AsyncIterator[Any]):
     return await ait.__anext__()
 
 
@@ -23,8 +23,15 @@ class Auth(ABC):
         pass
 
 
+class PublicAuth(Auth):
+    """Shim for unauthenticated API access."""
+
+    async def get_token(self) -> str:
+        return ""
+
+
 class TokenAuth(Auth):
-    def __init__(self, token):
+    def __init__(self, token: str):
         """Authentication for an access token.
 
         Args:
@@ -42,7 +49,7 @@ class TokenAuth(Auth):
 
 
 class AppAuth(Auth):
-    def __init__(self, app_id, privkey):
+    def __init__(self, app_id: int, privkey: str):
         """Authentication for a Github app.
 
         Args:
@@ -116,7 +123,7 @@ class AppInstallationAuth(Auth):
         self.app = app
         self.owner = owner
         self.repositories = repositories
-        self._client = Client(auth=self.app)
+        self._client = AsyncClient(auth=self.app)
         self._generator = self._gen_installation_token()
 
     async def close(self) -> None:
@@ -129,7 +136,10 @@ class AppInstallationAuth(Auth):
         Returns:
             str: The app's installation id.
         """
-        installations = await self._client.get("/app/installations")
+        async with await self._client.get("/app/installations") as response:
+            response.raise_for_status()
+            installations = await response.json()
+        assert isinstance(installations, list)
 
         for installation in installations:
             if installation["account"]["login"] == self.owner:
@@ -162,8 +172,12 @@ class AppInstallationAuth(Auth):
             # Ensures the token is only valid for the current repo.
             data["repositories"] = self.repositories
 
-        async def _gentoken():
-            return (await self._client.post(query, data=data))["token"]
+        async def _gentoken() -> str:
+            response = await self._client.post(query, data=data)
+            response.raise_for_status()
+            result = await response.json()
+            assert isinstance(result, dict)
+            return result["token"]
 
         token = await _gentoken()
         exp = int(time.time()) + 3600  # tokens are valid for one hour
